pub enum ColorChoice {
Auto,
Always,
Never,
}Expand description
User preference for emitting ANSI color escape codes.
Variants
Auto
Automatically enable color if writing to a TTY and environment allows it.
Always
Always emit ANSI color codes, even when redirected or piped.
Never
Never emit ANSI color codes.
Implementations
Sourceimpl ColorChoice
impl ColorChoice
Sourcepub fn should_color(self, is_terminal: bool) -> bool
pub fn should_color(self, is_terminal: bool) -> bool
Determine whether color should be active given the terminal/TTY status of the output.
Respects:
NO_COLOR(https://no-color.org)FORCE_COLOR(https://force-color.org)TERM=dumb- Stream TTY status
Sourcepub fn detect_auto(is_terminal: bool) -> bool
pub fn detect_auto(is_terminal: bool) -> bool
Automatically detect whether color is supported for the current environment.
Sourcepub fn detect_with(
is_terminal: bool,
get_var: impl Fn(&str) -> Option<String>,
) -> bool
pub fn detect_with( is_terminal: bool, get_var: impl Fn(&str) -> Option<String>, ) -> bool
Internal helper that tests environment variables using a mockable lookup closure.
Sourcepub fn resolve_stdout(self) -> bool
pub fn resolve_stdout(self) -> bool
Resolve whether stdout should currently display colors.
Sourcepub fn resolve_stderr(self) -> bool
pub fn resolve_stderr(self) -> bool
Resolve whether stderr should currently display colors.