pub struct InspectPath { /* private fields */ }Expand description
A path through an inspected value tree.
Paths represent navigation from a root value to a specific nested value, using field names and indices.
Examples
use inspect_core::{InspectPath, PathSegment};
let path = InspectPath::new()
.field("users")
.index(2)
.field("name");
assert_eq!(path.to_string(), "users[2].name");Implementations
Sourceimpl InspectPath
impl InspectPath
Sourcepub fn new() -> InspectPath
pub fn new() -> InspectPath
Create a new empty path.
Sourcepub fn field(self, name: impl Into<String>) -> InspectPath
pub fn field(self, name: impl Into<String>) -> InspectPath
Append a field access to this path.
Sourcepub fn index(self, idx: usize) -> InspectPath
pub fn index(self, idx: usize) -> InspectPath
Append an index access to this path.
Sourcepub fn segments(&self) -> &[PathSegment]
pub fn segments(&self) -> &[PathSegment]
Get the segments in this path.