Style

Struct Style 

pub struct Style { /* private fields */ }
A terminal style defining text effects and foreground/background colors.

When the color feature is enabled, this is backed by anstyle::Style which renders zero-allocation ANSI escape codes. When disabled, this is a zero-cost no-op type that emits nothing.

Implementations

Source

impl Style

pub const fn new() -> Style

Create a new, unstyled style.

pub const fn bold(self) -> Style

Set bold effect.

pub const fn dimmed(self) -> Style

Set dimmed/faint effect.

pub const fn italic(self) -> Style

Set italic effect.

pub const fn underline(self) -> Style

Set underline effect.

pub const fn fg_rgb(self, r: u8, g: u8, b: u8) -> Style

Set 24-bit Truecolor (RGB) foreground color.

pub const fn fg_ansi256(self, code: u8) -> Style

Set 8-bit ANSI 256-color palette foreground color.

pub const fn fg_ansi(self, color: AnsiColor) -> Style

Set 4-bit standard ANSI 16-color foreground color.

pub fn is_plain(&self) -> bool

True if no styling effects or colors are configured.

pub fn render(&self) -> impl Display

Render the ANSI sequence to activate this style.

pub fn render_reset(&self) -> impl Display

Render the ANSI sequence to reset styles.

pub const fn inner(&self) -> Style

Get the underlying anstyle::Style.

pub fn to_ansi256(self) -> Style

Convert this style’s colors to ANSI 256 colors.

pub fn to_ansi16(self) -> Style

Convert this style’s colors to standard 16 ANSI colors.

pub fn to_monochrome(self) -> Style

Strip all foreground/background colors, preserving effects like Bold and Dimmed.