TypeInfo

Struct TypeInfo 

pub struct TypeInfo<'a> { /* private fields */ }
Metadata about a type being inspected.

Provides name, path, and additional context about the type.

Implementations

Source

impl<'a> TypeInfo<'a>

pub fn new(name: impl Into<Cow<'a, str>>) -> TypeInfo<'a>

Create type information with just a name.

pub fn with_path( name: impl Into<Cow<'a, str>>, path: impl Into<Cow<'a, str>>, ) -> TypeInfo<'a>

Create type information with a name and module path.

pub fn name(&self) -> &str

The type’s name.

pub fn path(&self) -> Option<&str>

The type’s fully qualified path, if available.